Package: memuse
Title: Memory Estimation Utilities
Version: 4.2-3
Description: How much ram do you need to store a 100,000 by 100,000 matrix?
    How much ram is your current R session using? How much ram do you even have?
    Learn the scintillating answer to these and many more such questions with
    the 'memuse' package.
License: BSD 2-clause License + file LICENSE
Depends: R (>= 3.0.0)
Imports: methods, utils
NeedsCompilation: yes
ByteCompile: yes
Authors@R: c(
    person("Drew", "Schmidt", email="wrathematics@gmail.com", role=c("aut", "cre")),
    person("Christian", "Heckendorf", role="ctb", comment="FreeBSD improvements to meminfo"),
    person("Wei-Chen", "Chen", role="ctb", comment="Windows build fixes"),
    person("Dan", "Burgess", role="ctb", comment="donation of a Mac for development and testing"))
Maintainer: Drew Schmidt <wrathematics@gmail.com>
URL: https://github.com/shinra-dev/memuse
BugReports: https://github.com/shinra-dev/memuse/issues
RoxygenNote: 7.1.2
Packaged: 2023-01-23 17:13:06 UTC; mschmid3
Author: Drew Schmidt [aut, cre],
  Christian Heckendorf [ctb] (FreeBSD improvements to meminfo),
  Wei-Chen Chen [ctb] (Windows build fixes),
  Dan Burgess [ctb] (donation of a Mac for development and testing)
Repository: CRAN
Date/Publication: 2023-01-24 15:40:15 UTC
Built: R 4.4.0; x86_64-apple-darwin16.7.0; 2024-05-01 06:30:18 UTC; unix
