# Generated by roxygen2: do not edit by hand

S3method("[",sysinfo)
S3method(print,humanreadable)
S3method(print,sysinfo)
export(Sys.cachelinesize)
export(Sys.cachesize)
export(Sys.dirsize)
export(Sys.filesize)
export(Sys.meminfo)
export(Sys.pageinfo)
export(Sys.procmem)
export(Sys.swapinfo)
export(as.memuse)
export(howbig)
export(howmany)
export(hr)
export(memuse)
export(mu)
export(mu.names)
export(mu.prefix)
export(mu.size)
export(mu.unit)
export(swap.names)
export(swap.prefix)
export(swap.unit)
exportMethods("!=")
exportMethods("*")
exportMethods("+")
exportMethods("-")
exportMethods("/")
exportMethods("<")
exportMethods("<=")
exportMethods("==")
exportMethods(">")
exportMethods(">=")
exportMethods("^")
exportMethods(as.character)
exportMethods(as.memuse)
exportMethods(as.numeric)
exportMethods(memuse)
exportMethods(mu)
exportMethods(mu.names)
exportMethods(mu.prefix)
exportMethods(mu.size)
exportMethods(mu.unit)
exportMethods(print)
exportMethods(show)
exportMethods(sum)
exportMethods(swap.names)
exportMethods(swap.prefix)
exportMethods(swap.unit)
import(methods)
importFrom(utils,object.size)
useDynLib(memuse, R_meminfo_retvals, R_meminfo_raminfo, R_meminfo_swapinfo, R_meminfo_procinfo, R_meminfo_cacheinfo_size, R_meminfo_cacheinfo_linesize, R_meminfo_filesize)
